==> anwiba-spatial-data-ckan-1.0.68-sources.jar: net/anwiba/spatial/ckan/json/schema/v1_0/User.java <==
//Copyright (c) 2017 by Andreas W. Bartels (bartels@anwiba.de)
package net.anwiba.spatial.ckan.json.schema.v1_0;

import com.fasterxml.jackson.annotation.JsonProperty;

public class User {

    private String openid = null;
    private String about = null;
    private String display_name = null;
    private String name = null;
    private DateString created = null;
    private String email_hash = null;
    private Boolean sysadmin = Boolean.valueOf(false);
    private Boolean activity_streams_email_notifications = Boolean.valueOf(false);
    private String state = null;
    private Integer number_of_edits = Integer.valueOf(0);
    private String fullname = null;
    private String id = null;
    private Integer number_created_packages = Integer.valueOf(0);

    @JsonProperty("openid")
    public void setOpenid(final String openid) {
        this.openid = openid;
    }

    @JsonProperty("openid")
    public String getOpenid() {
        return this.openid;
    }

    @JsonProperty("about")
    public void setAbout(final String about) {
        this.about = about;
    }

    @JsonProperty("about")
    public String getAbout() {
        return this.about;
    }

    @JsonProperty("display_name")
    public void setDisplay_name(final String display_name) {
        this.display_name = display_name;
    }

    @JsonProperty("display_name")
    public String getDisplay_name() {
        return this.display_name;
    }

    @JsonProperty("name")
    public void setName(final String name) {
        this.name = name;
    }

    @JsonProperty("name")
    public String getName() {
        return this.name;
    }

    @JsonProperty("created")
    public void setCreated(final DateString created) {
        this.created = created;
    }

    @JsonProperty("created")
    public DateString getCreated() {
        return this.created;
    }

    @JsonProperty("email_hash")
    public void setEmail_hash(final String email_hash) {
        this.email_hash = email_hash;
    }

    @JsonProperty("email_hash")
    public String getEmail_hash() {
        return this.email_hash;
    }

    @JsonProperty("sysadmin")
    public void setSysadmin(final Boolean sysadmin) {
        this.sysadmin = sysadmin;
    }

    @JsonProperty("sysadmin")
    public Boolean isSysadmin() {
        return this.sysadmin;
    }

    @JsonProperty("activity_streams_email_notifications")
    public void setActivity_streams_email_notifications(final Boolean activity_streams_email_notifications) {
        this.activity_streams_email_notifications = activity_streams_email_notifications;
    }

    @JsonProperty("activity_streams_email_notifications")
    public Boolean isActivity_streams_email_notifications() {
        return this.activity_streams_email_notifications;
    }

    @JsonProperty("state")
    public void setState(final String state) {
        this.state = state;
    }

    @JsonProperty("state")
    public String getState() {
        return this.state;
    }

    @JsonProperty("number_of_edits")
    public void setNumber_of_edits(final Integer number_of_edits) {
        this.number_of_edits = number_of_edits;
    }

    @JsonProperty("number_of_edits")
    public Integer getNumber_of_edits() {
        return this.number_of_edits;
    }

    @JsonProperty("fullname")
    public void setFullname(final String fullname) {
        this.fullname = fullname;
    }

    @JsonProperty("fullname")
    public String getFullname() {
        return this.fullname;
    }

    @JsonProperty("id")
    public void setId(final String id) {
        this.id = id;
    }

    @JsonProperty("id")
    public String getId() {
        return this.id;
    }

    @JsonProperty("number_created_packages")
    public void setNumber_created_packages(final Integer number_created_packages) {
        this.number_created_packages = number_created_packages;
    }

    @JsonProperty("number_created_packages")
    public Integer getNumber_created_packages() {
        return this.number_created_packages;
    }

}

==> anwiba-spatial-data-ckan-1.0.154-sources.jar: net/anwiba/spatial/ckan/json/schema/v1_0/User.java <==
//Copyright (c) 2017 by Andreas W. Bartels
package net.anwiba.spatial.ckan.json.schema.v1_0;

import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonProperty;
import net.anwiba.spatial.ckan.json.types.DateString;

public class User {

    private String openid = null;
    private String about = null;
    private String display_name = null;
    private String name = null;
    private DateString created = null;
    private String email_hash = null;
    private Boolean sysadmin = Boolean.valueOf(false);
    private Boolean activity_streams_email_notifications = Boolean.valueOf(false);
    private String state = null;
    private Integer number_of_edits = Integer.valueOf(0);
    private String fullname = null;
    private String id = null;
    private Integer number_created_packages = Integer.valueOf(0);
    private final Map<java.lang.String, Object> _unknownMembers = new LinkedHashMap<java.lang.String, Object>();

    @JsonProperty("openid")
    public void setOpenid(final String openid) {
        this.openid = openid;
    }

    @JsonProperty("openid")
    public String getOpenid() {
        return this.openid;
    }

    @JsonProperty("about")
    public void setAbout(final String about) {
        this.about = about;
    }

    @JsonProperty("about")
    public String getAbout() {
        return this.about;
    }

    @JsonProperty("display_name")
    public void setDisplay_name(final String display_name) {
        this.display_name = display_name;
    }

    @JsonProperty("display_name")
    public String getDisplay_name() {
        return this.display_name;
    }

    @JsonProperty("name")
    public void setName(final String name) {
        this.name = name;
    }

    @JsonProperty("name")
    public String getName() {
        return this.name;
    }

    @JsonProperty("created")
    public void setCreated(final DateString created) {
        this.created = created;
    }

    @JsonProperty("created")
    public DateString getCreated() {
        return this.created;
    }

    @JsonProperty("email_hash")
    public void setEmail_hash(final String email_hash) {
        this.email_hash = email_hash;
    }

    @JsonProperty("email_hash")
    public String getEmail_hash() {
        return this.email_hash;
    }

    @JsonProperty("sysadmin")
    public void setSysadmin(final Boolean sysadmin) {
        this.sysadmin = sysadmin;
    }

    @JsonProperty("sysadmin")
    public Boolean isSysadmin() {
        return this.sysadmin;
    }

    @JsonProperty("activity_streams_email_notifications")
    public void setActivity_streams_email_notifications(final Boolean activity_streams_email_notifications) {
        this.activity_streams_email_notifications = activity_streams_email_notifications;
    }

    @JsonProperty("activity_streams_email_notifications")
    public Boolean isActivity_streams_email_notifications() {
        return this.activity_streams_email_notifications;
    }

    @JsonProperty("state")
    public void setState(final String state) {
        this.state = state;
    }

    @JsonProperty("state")
    public String getState() {
        return this.state;
    }

    @JsonProperty("number_of_edits")
    public void setNumber_of_edits(final Integer number_of_edits) {
        this.number_of_edits = number_of_edits;
    }

    @JsonProperty("number_of_edits")
    public Integer getNumber_of_edits() {
        return this.number_of_edits;
    }

    @JsonProperty("fullname")
    public void setFullname(final String fullname) {
        this.fullname = fullname;
    }

    @JsonProperty("fullname")
    public String getFullname() {
        return this.fullname;
    }

    @JsonProperty("id")
    public void setId(final String id) {
        this.id = id;
    }

    @JsonProperty("id")
    public String getId() {
        return this.id;
    }

    @JsonProperty("number_created_packages")
    public void setNumber_created_packages(final Integer number_created_packages) {
        this.number_created_packages = number_created_packages;
    }

    @JsonProperty("number_created_packages")
    public Integer getNumber_created_packages() {
        return this.number_created_packages;
    }

    @JsonAnySetter
    public void set(final java.lang.String name, final Object value) {
        Objects.requireNonNull(name);
        this._unknownMembers.put(name, value);
    }

    @JsonAnyGetter
    public Map<java.lang.String, Object> get() {
        if (this._unknownMembers.isEmpty()) {
            return null;
        }
        return this._unknownMembers;
    }

}
